==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24ToolBarDialog.h <==
// class javax.swing.plaf.basic.BasicToolBarUI$ToolBarDialog

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 6a0159196eecd68 java_awt_Dialog
// @dep_class 184d12f43c3697c9 java_awt_Window
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 76e1edcd9530dc7e javax_swing_JDialog
// @dep_class e7e025a9ce8e143a javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog

// header file dependencies
// @dep_header javax_swing_JDialog

#include "javax/swing/JDialog.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_java_awt_Dialog$vmethods	java_awt_Dialog;
	_jc_javax_swing_JDialog$vmethods	javax_swing_JDialog;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog;
    _jc_javax_swing_JDialog$sub_refs	javax_swing_JDialog;
    _jc_java_awt_Dialog$sub_refs	java_awt_Dialog;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_java_awt_Dialog$sub_nonrefs	java_awt_Dialog;
    _jc_javax_swing_JDialog$sub_nonrefs	javax_swing_JDialog;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicToolBarUI__24ToolBarDialog.h <==
// class javax.swing.plaf.basic.BasicToolBarUI$ToolBarDialog

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 6a0159196eecd68 java_awt_Dialog
// @dep_class fd4ae025aa56ceb9 java_awt_Window
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 76e1edcd9530dc7e javax_swing_JDialog
// @dep_class 8d14d62ee505059c javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog

// header file dependencies
// @dep_header javax_swing_JDialog

#include "javax/swing/JDialog.h"

#ifndef _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog_H_
#define _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$refs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$nonrefs	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$object	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vmethods	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtable	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$method$_init$bf41621710f83cec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$object *, struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_java_awt_Dialog$vmethods	java_awt_Dialog;
	_jc_javax_swing_JDialog$vmethods	javax_swing_JDialog;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vmethods	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicToolBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$refs {
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_refs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog;
    _jc_javax_swing_JDialog$sub_refs	javax_swing_JDialog;
    _jc_java_awt_Dialog$sub_refs	java_awt_Dialog;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_java_awt_Dialog$sub_nonrefs	java_awt_Dialog;
    _jc_javax_swing_JDialog$sub_nonrefs	javax_swing_JDialog;
    _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$sub_nonrefs	javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$object {
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$vtype _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicToolBarUI__24ToolBarDialog_H_ */
